<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/ecrire_?lang_cible=ca
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'activer_plugin' => 'Activar el connector',
	'affichage' => 'Presentació',
	'aide_non_disponible' => 'Aquesta part de l’ajuda en línia no està encara disponible en aquesta llengua.',
	'annuler_recherche' => 'Anul·lar la cerca',
	'auteur' => 'Autor:',
	'avis_acces_interdit' => 'Accès prohibit',
	'avis_article_modifie' => 'Atenció, @nom_auteur_modif@ ha treballat a aquest article fa @date_diff@ minuts',
	'avis_aucun_resultat' => 'Cap resultat',
	'avis_base_inaccessible' => 'Impossible connectar-se a la base de dades @base@.',
	'avis_chemin_invalide_1' => 'El camí que heu triat',
	'avis_chemin_invalide_2' => 'no sembla pas vàlid. Voleu tornar a la pàgina precedent i constrastar les informacions donades.',
	'avis_connexion_echec_1' => 'La connexió a la base de dades ha fracassat.',
	'avis_connexion_echec_2' => 'Tornar a la pàgina precedent per verificar les dades que heu ficat.',
	'avis_connexion_echec_3' => '<b>N.B.</b> A molts dels servidors, heu de <b>demanar</b> l’activació del vostre accés a la base de dades abans de poder-la utilitzar. Si no podeu connectar-vos, verifiqueu que heu efectuat aquest pas.',
	'avis_connexion_erreur_creer_base' => 'La base de dades no s’ha pogut crear.',
	'avis_connexion_erreur_nom_base' => 'El nom de la base només pot contenir lletres, xifres i guions',
	'avis_connexion_ldap_echec_1' => ' La connexió amb el servidor LDAP ha caigut.',
	'avis_connexion_ldap_echec_2' => 'Tornar a la pàgina precedent per verificar les dades que heu ficat.',
	'avis_connexion_ldap_echec_3' => 'Alternativament, no utilitzeu el support LDAP per a importar els usuaris.',
	'avis_deplacement_rubrique' => 'Atenció ! Aquesta secció conté @contient_breves@ breu@scb@ : si la moveu, assenyaleu-ho en aquesta casella de confirmació.',
	'avis_erreur_connexion_mysql' => 'Error de connexió SQL',
	'avis_espace_interdit' => '<b>Zona prohibida</b><div>SPIP ja està instal·lat.</div>',
	'avis_lecture_noms_bases_1' => 'El programa d’instal·lació no ha pogut llegir els noms de les bases de dades instal·lades.',
	'avis_lecture_noms_bases_2' => 'O bé cap base de dades no està disponible, o bé la funció que permet de llistar les bases ha estat
desactivada per raons de seguretat (cosa normal en molts proveïdors d’hostatge).',
	'avis_lecture_noms_bases_3' => 'En la segona alternativa, és probable que una base que porti el vostre nom d’usuari sigui utilitzable:',
	'avis_non_acces_page' => 'No teniu accés a aquesta pàgina.',
	'avis_operation_echec' => 'L’operació ha fracassat.',
	'avis_operation_impossible' => 'Operació impossible',
	'avis_suppression_base' => 'ATENCIÓ, la supressió de dades és irreversible.',

	// B
	'bouton_acces_ldap' => 'Afegir l’accés a LDAP',
	'bouton_ajouter' => 'Afegir',
	'bouton_annuler' => 'Anul·lar',
	'bouton_cache_activer' => 'Reactivar la memòria cau',
	'bouton_cache_desactiver' => 'Desactivar temporalment la memòria cau',
	'bouton_demande_publication' => 'Demanar la publicació d’aquest article',
	'bouton_desactive_tout' => 'Desactivar-ho tot',
	'bouton_desinstaller' => 'desinstal·lar ',
	'bouton_effacer_tout' => 'Esborrar-ho TOT',
	'bouton_envoyer_message' => 'Missatge definitiu : enviar',
	'bouton_fermer' => 'Tancar',
	'bouton_mettre_a_jour_base' => 'Actualització de la base de dades',
	'bouton_modifier' => 'Modificar',
	'bouton_radio_afficher' => 'Mostrar',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'Aparèixer a la llista de redactors connectats',
	'bouton_radio_envoi_annonces_adresse' => 'Enviar els anuncis a l’adreça:',
	'bouton_radio_envoi_liste_nouveautes' => 'Enviar la llista de novetats',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'No aparèixer a la llista de redactors/es ',
	'bouton_radio_non_envoi_annonces_editoriales' => 'No enviar anuncis editorials',
	'bouton_redirection' => 'REDIRECCIÓ',
	'bouton_relancer_installation' => 'Tornar a llançar la instal·lació',
	'bouton_suivant' => 'Següent',
	'bouton_tenter_recuperation' => 'Intentar reparar',
	'bouton_test_proxy' => 'Provar el proxy',
	'bouton_vider_cache' => 'Buidar la memòria cau',

	// C
	'cache_modifiable_webmestre' => 'Aquest paràmetre és modificable pel webmestre del lloc Web.',
	'calendrier_synchro' => 'Si utilitzeu un programari d’agenda compatible <b>iCal</b>, el podeu sincronitzar amb les informacions d’aquest lloc.',
	'config_activer_champs' => 'Activar els camps següents',
	'config_choix_base_sup' => 'indicar una base en aquest servidor',
	'config_erreur_base_sup' => 'SPIP no té accés a la llista de bases accesibles',
	'config_info_base_sup' => 'Si teniu altres bases de dades a interrogar per mitjà d’SPIP, amb el seu servidor SQL o amb un altre, el formulari que hi ha més avall, us permet declarar-les. Si deixeu alguns camps buits, s’utilitzaran els identificadors de connexió a la base principal.',
	'config_info_base_sup_disponibles' => 'Bases suplementàries ja consultables:',
	'config_info_enregistree' => 'La nova configuració s’ha enregistrat',
	'config_info_logos' => 'Cada element del lloc Web pòt tenir el seu logotip, com un «logotip d’imatge canviant»',
	'config_info_logos_utiliser' => 'Utilitzar els logotips',
	'config_info_logos_utiliser_non' => 'No utilitzar els logotips',
	'config_info_logos_utiliser_survol' => 'Utilitzar els logotips d’imatge canviant',
	'config_info_logos_utiliser_survol_non' => 'No utilitzar els logotips d’imatge canviant',
	'config_info_redirection' => 'Activant aquesta opció, podreu crear articles virtuals, simples referències d’articles publicats en altres llocs Web o fora d’SPIP.',
	'config_redirection' => 'Articles virtuals',
	'config_titre_base_sup' => 'Declaració d’una base suplementària',
	'config_titre_base_sup_choix' => 'Escolliu una base suplementària',
	'connexion_ldap' => 'Connexió:',
	'creer_et_associer_un_auteur' => 'Crear i associar un autor',

	// D
	'date_mot_heures' => 'hores',

	// E
	'ecran_securite' => '+ pantalla de seguretat @version@',
	'email' => 'correu electrònic',
	'email_2' => 'correu electrònic:',
	'en_savoir_plus' => 'Per més informació',
	'entree_adresse_annuaire' => 'Adreça del directori',
	'entree_adresse_email' => 'L’adreça electrònica ',
	'entree_adresse_email_2' => 'Correu electrònic',
	'entree_base_donnee_1' => 'Adreça de la base de dades',
	'entree_base_donnee_2' => '(Sovint aquesta adreça correspon a la del vostre lloc, a vegades correspon a la menció «localhost», altres vegades es deixa totalment buida.)',
	'entree_biographie' => 'Biografia curta i en poques paraules.',
	'entree_chemin_acces' => '<b>Entrar</b> el camí d’accés:',
	'entree_cle_pgp' => 'La vostra clau PGP',
	'entree_cle_pgp_2' => 'Clau PGP',
	'entree_contenu_rubrique' => '(Contingut de la secció, en poques paraules.)',
	'entree_identifiants_connexion' => 'Els vostres identificadors de connexió...',
	'entree_identifiants_connexion_2' => 'Identificadors de connexió',
	'entree_informations_connexion_ldap' => 'Entreu en aquest formulari les informacions de connexió del vostre directori LDAP.
 L’administrador del sistema o de la xarxa us pot donar aquestes informacions.
   ',
	'entree_infos_perso' => 'Qui sóu?',
	'entree_infos_perso_2' => 'Qui és l’autor?',
	'entree_interieur_rubrique' => 'A l’interior de la secció:',
	'entree_liens_sites' => '<b>Enllaç hipertext</b> (referència, indret a visitar...)',
	'entree_login' => 'El vostre nom d’usuari',
	'entree_login_connexion_1' => 'El nom d’usuari de connexió',
	'entree_login_connexion_2' => '(A vegades correspon al vostre nom d’usuari d’accés a l’FTP; a vegades s’ha de deixar buit)',
	'entree_mot_passe' => 'La contrasenya',
	'entree_mot_passe_1' => 'La contrasenya de connexió',
	'entree_mot_passe_2' => '(A vegades correspon a la vostra contrasenya FTP; a vegades es deixa buit)',
	'entree_nom_fichier' => 'Introduir el nom del fitxer @texte_compresse@:',
	'entree_nom_pseudo' => 'El vostre nom o pseudònim',
	'entree_nom_pseudo_1' => '(El vostre nom o el vostre pseudònim)',
	'entree_nom_pseudo_2' => 'Nom o pseudònim ',
	'entree_nom_site' => 'El nom del vostre lloc',
	'entree_nom_site_2' => 'Nom del lloc de l’autor',
	'entree_nouveau_passe' => 'Una nova contrasenya',
	'entree_passe_ldap' => 'Contrasenya',
	'entree_port_annuaire' => 'Número de port del directori',
	'entree_signature' => 'Secció',
	'entree_titre_obligatoire' => '<b>Títol</b> [Obligatori]<br />',
	'entree_url' => 'L’adreça (URL) del vostre lloc',
	'entree_url_2' => 'Adreça (URL) del lloc',
	'erreur_connect_deja_existant' => 'Ja existeix un servidor amb aquest nom',
	'erreur_email_deja_existant' => 'Aquesta adreça email està ja registrada.',
	'erreur_nom_connect_incorrect' => 'Aquest nom de servidor no està autoritzat',
	'erreur_plugin_attribut_balise_manquant' => 'Atribut @attribut@ que manca a l’etiqueta @balise@.',
	'erreur_plugin_desinstalation_echouee' => 'La desinstal·lació del connector ha fracassat. No obstant el podeu desactivar. ',
	'erreur_plugin_fichier_absent' => 'Fitxer absent',
	'erreur_plugin_fichier_def_absent' => 'Fitxer de definició absent',
	'erreur_plugin_nom_fonction_interdit' => 'Nom de funció prohibit',
	'erreur_plugin_nom_manquant' => 'Falta el nom del connector',
	'erreur_plugin_prefix_manquant' => 'Espai de nom del connector no definit',
	'erreur_plugin_tag_plugin_absent' => 'falta el &lt;plugin&gt; al fitxer de definició',
	'erreur_plugin_version_manquant' => 'Falta la versió del connector',

	// H
	'htaccess_a_simuler' => 'Advertiment: la configuració del vostre servidor HTTP no té en compte els fitxers @htaccess@. Per garantir-vos una bona seguretat, heu de modificar aquesta configuració en aquest punt, o bé fer que les constants @constantes@ (es defineixen al fitxer mes_options.php) tinguin com a valor els directoris a fora de @document_root@.',
	'htaccess_inoperant' => 'htaccess inoperant',

	// I
	'ical_info1' => 'Aquesta pàgina mostra diferents maneres per estar en contacte amb la vida d’aquest lloc.',
	'ical_info2' => 'Per tenir més informacions sobre aquestes tècniques, no dubteu a consultar <a href="@spipnet@">la documentació d’SPIP</a>.',
	'ical_info_calendrier' => 'Hi ha dos calendaris a la vostra disposició. El primer és un mapa del lloc que mostra tots els articles publicats. El segon conté els anuncis editorials a més dels vostres darrers missatges privats: està reservat per vosaltres gràcies a una clau personal, que podeu modificar en tot moment renovant la vostra contrasenya. ',
	'ical_methode_http' => 'Descàrrega',
	'ical_methode_webcal' => 'Sincronització (webcal://)',
	'ical_texte_js' => 'Els articles publicats en aquest lloc poden ser mostrats fàcilment, en qualsevol lloc vostre, mitjançant una línia de javascript. ',
	'ical_texte_prive' => 'Aquest calendari, d’ús estrictament personal, us informa de l’activitat editorial privada d’aquest lloc (feines i cites personals, articles i breus proposats...).',
	'ical_texte_public' => 'Aquest calendari us permet seguir l’activitat pública d’aquest lloc (articles i breus publicats).',
	'ical_texte_rss' => 'Podeu sindicar les novetats d’aquest lloc mitjançant qualsevol lector de fitxers en format XML/RSS (Rich Site Summary). Aquest és també el format que permet a SPIP llegir les novetats publicades en altres llocs que utilitzen un format d’intercanvi compatible. ',
	'ical_titre_js' => 'Javascript',
	'ical_titre_mailing' => 'Llista de correu',
	'ical_titre_rss' => 'Fitxers de sindicació',
	'icone_accueil' => 'Inici',
	'icone_activer_cookie' => 'Activar la galeta de correspondència',
	'icone_activite' => 'Retroacció',
	'icone_admin_plugin' => 'Gestió dels connectors',
	'icone_administration' => 'Manteniment',
	'icone_afficher_auteurs' => 'Mostrar els autors',
	'icone_afficher_visiteurs' => 'Mostrar els visitants',
	'icone_arret_discussion' => 'No participar més en aquesta conversa',
	'icone_calendrier' => 'Calendari',
	'icone_configuration' => 'Configuració',
	'icone_creer_auteur' => 'Crear un nou autor i associar-lo a aquest article',
	'icone_creer_mot_cle' => 'Crear una nova paraula clau i lligar-la a aquest article',
	'icone_creer_rubrique_2' => 'Crear una nova secció',
	'icone_developpement' => 'Desenvolupament',
	'icone_edition' => 'Edició',
	'icone_ma_langue' => 'La meva llengua',
	'icone_mes_infos' => 'Les meves informacions',
	'icone_mes_preferences' => 'Les meves preferències',
	'icone_modifier_article' => 'Modificar aquest article',
	'icone_modifier_rubrique' => 'Modificar aquesta secció',
	'icone_publication' => 'Publicació',
	'icone_relancer_signataire' => 'Tornar a iniciar el signant',
	'icone_retour' => 'Tornar',
	'icone_retour_article' => 'Tornar a l’article',
	'icone_squelette' => 'Esquelets',
	'icone_suivi_publication' => 'Seguiment de la publicació',
	'icone_supprimer_cookie' => 'Suprimir la galeta de correspondència',
	'icone_supprimer_rubrique' => 'Suprimir aquesta secció',
	'icone_supprimer_signature' => 'Suprimir aquesta secció',
	'icone_valider_signature' => 'Validar aquesta signatura',
	'image_administrer_rubrique' => 'Podeu administrar aquesta secció',
	'info_1_article' => '1 article',
	'info_1_auteur' => '1 autor',
	'info_1_message' => '1 missatge',
	'info_1_mot_cle' => '1 paraula clau',
	'info_1_rubrique' => '1 secció',
	'info_1_visiteur' => '1 visitant',
	'info_activer_cookie' => 'Podeu activar una <b>galeta de correspondència</b>, us permetrà passar fàcilment del lloc públic al lloc privat.',
	'info_activer_menu_developpement' => 'Afegir el menú Desenvolupament',
	'info_admin_etre_webmestre' => 'Donar-me els drets d’administrador',
	'info_admin_je_suis_webmestre' => 'Sóc <b>administrador</b>',
	'info_admin_statuer_webmestre' => 'Donar a aquest administrador els drets de webmestre',
	'info_admin_webmestre' => 'Aquest administrador és <b>webmestre</b>',
	'info_administrateur' => 'Administrador',
	'info_administrateur_1' => 'Administrador',
	'info_administrateur_2' => ' del lloc (<i>utilitzar amb precaució</i>)',
	'info_administrateur_site_01' => 'Si sóu administrador del lloc, vulgueu ',
	'info_administrateur_site_02' => 'feu un clic sobre aquest link',
	'info_administrateurs' => 'Administradors',
	'info_administrer_rubrique' => 'Podeu administrar aquesta secció',
	'info_adresse' => 'a l’adreça:',
	'info_adresse_desinscription' => 'Adreça de desinscripció:',
	'info_adresse_url' => 'Adreça (URL) del lloc públic',
	'info_afficher_par_nb' => 'Mostrar per',
	'info_aide_en_ligne' => 'Ajuda en línia d’SPIP',
	'info_ajout_image' => 'Quan afegiu imatges com a documents adjunts en un article, l’SPIP pot crear automàticament imatges en miniatura de les imatges inserides. Això permet, per exemple, la creació automàtica d’una galeria o d’un portafoli.',
	'info_ajouter_rubrique' => 'Afegir una altra secció per administrar:',
	'info_annonce_nouveautes' => 'Avís de les novetats',
	'info_article' => 'article',
	'info_article_2' => 'articles',
	'info_article_a_paraitre' => 'Els articles per publicar amb data posterior ',
	'info_articles_02' => 'articles',
	'info_articles_2' => 'Articles',
	'info_articles_auteur' => 'Articles d’aquest autor',
	'info_articles_miens' => 'Els meus articles',
	'info_articles_tous' => 'Tots els articles',
	'info_articles_trouves' => 'Articles trobats',
	'info_attente_validation' => 'Els vostres articles en espera de validació',
	'info_aucun_article' => 'Cap article',
	'info_aucun_auteur' => 'Cap autor',
	'info_aucun_message' => 'Cap missatge',
	'info_aucun_rubrique' => 'Cap secció',
	'info_aujourdhui' => 'avui:',
	'info_auteur_gere_toutes_rubriques' => 'Aquest autor gestiona <b>totes les seccions</b>',
	'info_auteur_gere_toutes_rubriques_2' => 'Gestiono <b>totes les seccions</b>', # MODIF
	'info_auteurs' => 'Els autors',
	'info_auteurs_par_tri' => 'Autors@partri@',
	'info_auteurs_trouves' => 'Autors trobats',
	'info_authentification_externe' => 'Autenticació externa',
	'info_avertissement' => 'Avís',
	'info_barre_outils' => 'amb la seva barra d’eines?',
	'info_base_installee' => 'L’estructura de la vostra bases de dades s’ha instal·lat.',
	'info_bio' => 'Biografia',
	'info_cache_desactive' => 'La memòria cau està temporalment desactivada.',
	'info_chapeau' => 'Encapçalament',
	'info_chapeau_2' => 'Encapçalament:',
	'info_chemin_acces_1' => 'Opcions: <b>Camí d’accés al directori</b>',
	'info_chemin_acces_2' => 'Des d’ara, heu de configurar el camí d’accés a la informació del directori. Aquesta informació és essencial per llegir els perfils dels usuaris guardats al directori.',
	'info_chemin_acces_annuaire' => 'Opcions: <b>Camí d’accés al directori',
	'info_choix_base' => 'Tercer pas:',
	'info_classement_1' => '<sup>r</sup> a la @liste@',
	'info_classement_2' => '<sup>n</sup> a la @liste@',
	'info_code_acces' => 'No oblideu els vostres codis d’accés!',
	'info_compatibilite_html' => 'Norma HTML a seguir',
	'info_config_suivi' => 'Si aquesta adreça correspon a una llista de correu, podeu indicar més avall l’adreça a la que els participants es poden registrar. Aquesta adreça pot ser una URL (per exemple la pàgina de registre a la llista per la Web), o un correu electrònic amb un assumpte específic: <tt>@adresse_suivi@?assumpte=subscriure’s</tt>):',
	'info_config_suivi_explication' => 'Us podeu subscriure a la llista de correu d’aquest lloc. Si ho feu, rebreu per correu electrònic els anuncis dels articles i de les breus que es proposen per ser publicats.',
	'info_confirmer_passe' => 'Confirmar la nova contrasenya:',
	'info_conflit_edition_avis_non_sauvegarde' => 'Atenció, els següents camps han estat modificats en alguna altra banda. Per tant, les modificacions que s’hagin pogut en aquests camps no s’han gravat. ',
	'info_conflit_edition_differences' => 'Diferències:',
	'info_conflit_edition_version_enregistree' => 'La versió enregistrada:',
	'info_conflit_edition_votre_version' => 'La vostra versió:',
	'info_connexion_base' => 'Intent de connexió a la base de dades',
	'info_connexion_base_donnee' => 'Connexió amb la vostra base de dades',
	'info_connexion_ldap_ok' => 'La connexió LDAP ha reeixit.</b><p> Podeu passar a la següent etapa.</p>',
	'info_connexion_mysql' => 'La vostra connexió SQL',
	'info_connexion_ok' => 'La connexió ha reexit.',
	'info_contact' => 'Contacte',
	'info_contenu_articles' => 'Contingut dels articles',
	'info_contributions' => 'Contribucions',
	'info_creation_paragraphe' => 'Per crear paràgrafs, deixeu simplement unes línies buides.',
	'info_creation_rubrique' => 'Abans de poder escriure articles,<br /> heu de crear com a mínim una secció.<br />',
	'info_creation_tables' => 'Creació de les taules de la base de dades',
	'info_creer_base' => '<b>Crear</b> una nova base de dades:',
	'info_dans_rubrique' => 'Dins la secció:',
	'info_date_publication_anterieure' => 'Data de redacció anterior:',
	'info_date_referencement' => 'DATA DE REFERÈNCIA D’AQUEST LLOC:',
	'info_derniere_etape' => 'S’ha acabat!',
	'info_descriptif' => 'Descripció:',
	'info_desinstaller_plugin' => 'elimina les dades i desactiva el plugin',
	'info_discussion_cours' => 'Discussions en curs',
	'info_ecrire_article' => 'Abans de poder escriure un article, heu de crear com a mínim una secció.',
	'info_email_envoi' => 'L’adreça electrònica del remitent (opcional)',
	'info_email_envoi_txt' => 'Introduiu aquí l’adreça a fer servir per enviar els correus electrònics (per defecte, l’adreça del destinatari serà utilitzada com a adreça del remitent):',
	'info_email_webmestre' => 'Adreça electrònica del webmestre (opcional)',
	'info_envoi_email_automatique' => 'Enviament automàtic de correus electrònics',
	'info_envoyer_maintenant' => 'Envia-ho ara',
	'info_etape_suivante' => 'Passar a l’etapa següent',
	'info_etape_suivante_1' => 'Pot passar a l’etapa següent.',
	'info_etape_suivante_2' => 'Pot passar a l’etapa següent.',
	'info_exceptions_proxy' => 'Excepcions pel proxy',
	'info_exportation_base' => ' exportació de la base cap a @archive@',
	'info_facilite_suivi_activite' => 'Per tal de facilitat el seguiment de l’activitat editorial, SPIP pot fer arribar per correu electrònic, per exemple a una llista de correu dels redactors, l’avís de les peticions de publicació i de les validacions dels articles.',
	'info_fichiers_authent' => 'Fitxers d’autentificació « .htpasswd »',
	'info_forums_abo_invites' => 'El seu lloc Web proporciona fòrums pels abonats; en el lloc públic els visitants són convidats a enregistrar-se.',
	'info_gauche_admin_tech' => '<b>Només els responsables del lloc tenen accés a aquesta pàgina.</b><p> Dóna accés a les diferents funcions de manteniment tècnic. Algunes d’aquestes necessiten un procés d’autenticació específic que requereix disposar d’un accés FTP al lloc Web.</p>',
	'info_gauche_admin_vider' => '<b>Només els responsables del lloc tenen accés a aquesta pàgina.</b><p> Dóna accés a les diferents funcions de manteniment tècnic. Algunes d’aquestes necessiten un procés d’autenticació específic que requereix disposar d’un accés FTP al lloc Web.</p>',
	'info_gauche_auteurs' => 'Aquí hi trobareu tots els autors del lloc.
 El seu estat s’indica pel color de la seva icona (administrador = verd; redactor = groc).',
	'info_gauche_auteurs_exterieurs' => 'Els autors externs, sense accés al lloc web, estan indicats amb una icona blava;
 els autors esborrats amb una icona grissa.',
	'info_gauche_messagerie' => 'La missatgeria us permet intercanviar missatges entre els redactors, conservar recordatoris (pel vostre ús personal) o mostrar avisos a la pàgina inicial de l’espai privat (si sóu administrador).',
	'info_gauche_statistiques_referers' => 'Aquesta pàgina mostra la llista de  <i>referidors</i>, és a dir, dels llocs que contenen enllaços cap al vostre propi lloc Web, únicament per ahir i avui; aquesta llista es posa a zero cada 24 hores. ',
	'info_gauche_visiteurs_enregistres' => 'Aquí hi trobareu els visitants registrats
 a l’espai públic del lloc (fòrums per subscripció).',
	'info_generation_miniatures_images' => 'Generació de miniatures d’imatges',
	'info_gerer_trad_objets' => '@objets@ : administrar els enllaços de traducció',
	'info_hebergeur_desactiver_envoi_email' => 'Alguns proveïdors d’hostatge desactiven l’enviament automàtic de correus electrònics des dels seus servidors. En aquest cas, les següents funcions d’SPIP no funcionen. ',
	'info_hier' => 'ahir:',
	'info_identification_publique' => 'La vostra identitat pública...',
	'info_image_process' => 'Vulgueu seleccionar el millor mètode de fabricació de vinyetes fent un clic damunt de la imatge corresponent. ',
	'info_image_process2' => '<b>N.B.</b> <i>Si no apareix cap imatge, aleshores és que el servidor que allotja el vostre lloc web no ha estat configurat per utilitzar aquestes eines. Si desitgeu emprar aquestes funcions, poseu-vos en contacte amb el responsable tècnic i demaneu les extensions «GD» o «Imagick».</i>',
	'info_images_auto' => 'Imatges calculades automàticament',
	'info_informations_personnelles' => 'Informacions personals',
	'info_inscription' => 'Inscripció le',
	'info_inscription_automatique' => 'Inscripció automàtica dels nous redactors',
	'info_jeu_caractere' => 'Joc de caràcters del lloc',
	'info_jours' => 'dies',
	'info_laisser_champs_vides' => 'deixar els camps buits)',
	'info_langues' => 'Idiomes del lloc',
	'info_ldap_ok' => 'L’autenticació LDAP està instal·lada.',
	'info_lien_hypertexte' => 'Enllaç hipertext:',
	'info_liste_nouveautes_envoyee' => 'La lliste de les novetats ha estat enviada',
	'info_liste_redacteurs_connectes' => 'Llista de redactors connectats',
	'info_login_existant' => 'Aquest nom d’usuari ja existeix.',
	'info_login_trop_court' => 'Nom d’usuari massa curt.',
	'info_login_trop_court_car_pluriel' => 'L’usuari ha de tenir com a mínim @nb@ caràcters.',
	'info_logos' => 'Els logotips',
	'info_maximum' => 'màxim:',
	'info_meme_rubrique' => 'Dins la mateixa secció',
	'info_message_en_redaction' => 'Els vostres missatges en curs de redacció',
	'info_message_technique' => 'Missatge tècnic:',
	'info_messagerie_interne' => 'Missatgeria interna',
	'info_mise_a_niveau_base' => 'actualització de la vostra base de dades SQL',
	'info_mise_a_niveau_base_2' => '{{Atenció!}} Heu instal·lat una versió dels fitxers d’SPIP {anterior} a la que hi havia anteriorment en aquest lloc: correu el risc de perdre la vostra base de dades i que el vostre lloc deixi de funcionar.<br />{{Torneu a instal·lar els fitxers d’SPIP.}}',
	'info_modification_enregistree' => 'La vostra modificació s’ha enregistrat',
	'info_modifier_auteur' => 'Modificar l’autor:',
	'info_modifier_rubrique' => 'Modificar la secció:',
	'info_modifier_titre' => 'Modificar : @titre@',
	'info_mon_site_spip' => 'El meu lloc SPIP',
	'info_moyenne' => 'mitjana:',
	'info_multi_cet_article' => 'Idioma d’aquest article:',
	'info_multi_langues_choisies' => 'Seleccioneu a continuació els idiomes a disposició dels redactors del vostre lloc.
  Els idiomes ja utilitzats en el vostre lloc (visualitzats en primer lloc) no es poden desactivar.',
	'info_multi_objets' => '@objets@ : activar el menú de llengua',
	'info_multi_secteurs' => '... només per les seccions situades a l’arrel?',
	'info_nb_articles' => '@nb@ articles',
	'info_nb_auteurs' => '@nb@ autors',
	'info_nb_messages' => '@nb@ missatges',
	'info_nb_mots_cles' => '@nb@ paraules clau',
	'info_nb_rubriques' => '@nb@ seccions',
	'info_nb_visiteurs' => '@nb@ visitants',
	'info_nom' => 'Nom',
	'info_nom_destinataire' => 'Nom del destinatari',
	'info_nom_pas_conforme' => 'les etiquetes html no estàn permeses',
	'info_nom_site' => 'Nom del vostre lloc',
	'info_nombre_articles' => '@nb_articles@ articles,',
	'info_nombre_rubriques' => '@nb_rubriques@ seccions,',
	'info_nombre_sites' => '@nb_sites@ llocs,',
	'info_non_deplacer' => 'No desplaçar...',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP pot enviar, regularment, un avís amb les darreres novetats del lloc
  (articles i breus publicats recentment).',
	'info_non_envoi_liste_nouveautes' => 'No enviar la llista de novetats',
	'info_non_modifiable' => 'no pot ser modificat',
	'info_non_suppression_mot_cle' => 'no vull suprimir aquesta paraula clau.',
	'info_notes' => 'Notes',
	'info_nouvel_article' => 'Nou article',
	'info_nouvelle_traduction' => 'Nova traducció:',
	'info_numero_article' => 'ARTICLE NÚMERO:',
	'info_obligatoire_02' => '[obligatori]',
	'info_option_accepter_visiteurs' => 'Acceptar la inscripció dels visitants del lloc públic',
	'info_option_ne_pas_accepter_visiteurs' => 'Refusar la inscripció de visitants',
	'info_options_avancees' => 'OPCIONS AVANÇADES',
	'info_ou' => 'o...',
	'info_page_interdite' => 'Pàgina prohibida',
	'info_par_nom' => 'per nom',
	'info_par_nombre_article' => 'per nombre d’articles',
	'info_par_statut' => 'per estat',
	'info_par_tri' => '’(par @tri@)’',
	'info_passe_trop_court' => 'Contrasenya massa curta.',
	'info_passe_trop_court_car_pluriel' => 'La contrasenya ha de tenir com a mínim @nb@ caràcters.',
	'info_passes_identiques' => 'Les dues contrasenyes no són idèntiques.',
	'info_plus_cinq_car' => 'més de 5 caràcters',
	'info_plus_cinq_car_2' => '(Més de 5 caràcters)',
	'info_plus_trois_car' => '(Més de 3 caràcters)',
	'info_popularite' => 'popularitat: @popularite@ ; visites: @visites@',
	'info_post_scriptum' => 'Postdata',
	'info_post_scriptum_2' => 'Postdata:',
	'info_pour' => 'per',
	'info_preview_texte' => 'És possible previsualitzar el lloc com si tots els articles i breus (que almenys tinguen l’estat de "proposats") estigueren publicats. Aquesta possibilitat ha d’estar oberta només als administradors, a tots els redactors, o a ningú?', # MODIF
	'info_procedez_par_etape' => 'procediu pas per pas',
	'info_procedure_maj_version' => 'El procés d’actualització s’ha de tornar a arrancar per tal d’adaptar la base de dades a la nova versió d’SPIP.',
	'info_proxy_ok' => 'Test del proxy amb èxit.',
	'info_ps' => 'P.-S.',
	'info_publier' => 'publicar',
	'info_publies' => 'Els vostres articles publicats en línia',
	'info_question_accepter_visiteurs' => 'Si a les plantilles (esquelets) del vostre lloc Web es preveu l’enregistrament de visitants sense accés a l’espai privat, vulgueu activar la següent opció:',
	'info_question_inscription_nouveaux_redacteurs' => 'Accepteu les inscripcions de nous redactors a partir del lloc web públic? Si ho accepteu, els visitants es podran inscriure
 mitjançant un formulari  automatitzat i llavors accediran a l’espai privat per proposar els seus propis articles.<blockquote><i>Durant el procés d’inscripció, els usuaris reben un correu electrònic automàtic en el que se’ls dóna els seus codis d’accés a la web privada. Alguns proveïdors d’hostatge desactiven l’enviament de correus electrònics des dels seus servidors: en aquest
 cas, la inscripció automàtica és impossible.</i></blockquote>',
	'info_qui_edite' => '@nom_auteur_modif@ ha treballat en aquest contingut fa @date_diff@ minuts',
	'info_racine_site' => 'Arrel del lloc',
	'info_recharger_page' => 'Actualitzeu aquesta pàgina en breus instants.',
	'info_recherche_auteur_zero' => 'Cap resultat per « @cherche_auteur@ ».',
	'info_recommencer' => 'Torneu-ho a provar.',
	'info_redacteur_1' => 'Redactor',
	'info_redacteur_2' => 'tenint accés a l’espai privat (<i>recomanat</i>)',
	'info_redacteurs' => 'Redactors',
	'info_redaction_en_cours' => 'En procés de redacció',
	'info_redirection' => 'Redireccionament',
	'info_redirection_activee' => 'La redirecció està activada.',
	'info_redirection_boucle' => 'Tracta de redirigir l’article sobre ell mateix.',
	'info_redirection_desactivee' => 'S’ha suprimit la redirecció.',
	'info_refuses' => 'Els vostres articles rebutjats',
	'info_reglage_ldap' => 'Opcions: <b>Posta a punt de la importació LDAP</b>',
	'info_renvoi_article' => '<b>Redirecció.</b> Aquest article et porta a la pàgina:',
	'info_reserve_admin' => 'Només els adminsitradors poden modificar aquesta adreça.',
	'info_restreindre_rubrique' => 'Restringir la gestió a les seccions:',
	'info_resultat_recherche' => 'Resultats de la cerca:',
	'info_rubriques' => 'Seccions',
	'info_rubriques_02' => 'seccions',
	'info_rubriques_trouvees' => 'Seccions trobades',
	'info_sans_titre' => 'Sense títol',
	'info_selection_chemin_acces' => '<b>Seleccioneu</b> a continuació el camí d’accés en el directori:',
	'info_signatures' => 'signatures',
	'info_site' => 'Lloc',
	'info_site_2' => 'lloc:',
	'info_site_min' => 'lloc',
	'info_site_reference_2' => 'Lloc referenciat',
	'info_site_web' => 'Lloc Web:',
	'info_sites' => 'llocs',
	'info_sites_lies_mot' => 'Els llocs referenciats lligats a aquesta paraula clau',
	'info_sites_proxy' => 'Utilitzar un proxy',
	'info_sites_trouves' => 'Llocs trobats',
	'info_sous_titre' => 'Subtítol:',
	'info_statut_administrateur' => 'Administrador',
	'info_statut_auteur' => 'Estatus d’aquest autor:',
	'info_statut_auteur_2' => 'Sóc',
	'info_statut_auteur_a_confirmer' => 'Inscripció per confirmar',
	'info_statut_auteur_autre' => 'Un altre estat:',
	'info_statut_redacteur' => 'Redactor',
	'info_statut_utilisateurs_1' => 'Estat per defecte dels usuaris importats',
	'info_statut_utilisateurs_2' => 'Escolliu l’estat atribuït a les persones que hi ha al directori LDAP quan es connecten per primera vegada. Posteriorment podreu podreu modificar aquest valor cas per cas.',
	'info_suivi_activite' => 'Seguiment de l’activitat editorial',
	'info_surtitre' => 'Sobretítol:',
	'info_syndication_integrale_1' => 'El vostre lloc Web proposa fitxers de sindicació (veure « <a href="@url@">@titre@</a> »).',
	'info_syndication_integrale_2' => 'Desitgeu transmetre els articles en la seva totalitat, o difondre’n només alguns centenars de caràcters?',
	'info_table_prefix' => 'Podeu modificar el prefix del nom de les taules de dades (aquest és indispensable quan es volen instal·lar diversos llocs Web en una mateixa base de dades). Aquest prefix s’escriu en lletres minúscules, sense accents i sense espais.',
	'info_taille_maximale_images' => 'SPIP provara la mida màxima de les imatges que pot tractar (en milions de píxels).<br /> Les imatges més grans no es reduiran. ',
	'info_taille_maximale_vignette' => 'Mida màxima de les vinyetes generades pel sistema:',
	'info_terminer_installation' => 'Ara podeu finalitzar el procés d’instal·lació estàndard. ',
	'info_texte' => 'Text',
	'info_texte_explicatif' => 'Text explicatiu',
	'info_texte_long' => '(el text és llarg: es mostra en diverses parts que seran ajuntades després de la validació.)',
	'info_texte_message' => 'Text del vostre missatge:',
	'info_texte_message_02' => 'Text del missatge',
	'info_titre' => 'Títol:',
	'info_total' => 'total :',
	'info_tous_articles_en_redaction' => 'Tots els articles en procés de redacció',
	'info_tous_articles_presents' => 'Tots els articles publicats en aquesta secció',
	'info_tous_articles_refuses' => 'Tots els articles refusats',
	'info_tous_les' => 'tots els:',
	'info_tout_site' => 'Tot el lloc',
	'info_tout_site2' => 'L’article no ha estat traduït a aquesta llengua. ',
	'info_tout_site3' => 'L’article ha estat traduït a aquesta llengua, però s’han fet modificacions a l’article de referència. La traducció s’ha de posar al dia.',
	'info_tout_site4' => 'L’article ha estat traduït a aquesta llengua i la traducció posada al dia. ',
	'info_tout_site5' => 'Article original.',
	'info_tout_site6' => '<b>Atenció:</b> només es mostren els articles originals.
Les traduccions estan associades a l’original,
amb un color que indica el seu estat:',
	'info_traductions' => 'Traduccions',
	'info_travail_colaboratif' => 'Treball col·lectiu en els articles',
	'info_un_article' => 'un article,',
	'info_un_site' => 'un lloc,',
	'info_une_rubrique' => 'una secció,',
	'info_une_rubrique_02' => '1 secció',
	'info_url' => 'URL:',
	'info_url_proxy' => 'URL del proxy',
	'info_url_site_pas_conforme' => 'l’URL del lloc web no és vàlida',
	'info_url_test_proxy' => 'URL de test',
	'info_urlref' => 'Enllaç hipertext:',
	'info_utilisation_spip' => 'Podeu començar a utilitzar el sistema de publicació assistida...',
	'info_visites_par_mois' => 'Mostrar per mes:',
	'info_visiteur_1' => 'Visitant',
	'info_visiteur_2' => 'del lloc públic',
	'info_visiteurs' => 'Visitants',
	'info_visiteurs_02' => 'Visitants del lloc públic',
	'info_webmestre_forces' => 'Els administradors estan definits a <tt>@file_options@</tt>.',
	'install_adresse_base_hebergeur' => 'Adreça de la base de dades donada per l’hostatjador',
	'install_connect_ok' => 'La nova base de dades ha estat correctament declarada amb el nom del servidor @connect@.',
	'install_echec_annonce' => 'La instal·lació probablement fracassarà, o anirà a parar a un lloc no funcional...',
	'install_extension_mbstring' => 'SPIP no funciona amb :',
	'install_extension_php_obligatoire' => 'SPIP exigeix l’extensió php :',
	'install_login_base_hebergeur' => 'Login de connexió donat per l’hostatjador',
	'install_nom_base_hebergeur' => 'Nom de la base que ens ha donat l’hostatjador:',
	'install_pas_table' => 'Base actualment sense taules',
	'install_pass_base_hebergeur' => 'Contrasenya de connexió donada per l’hostatjador',
	'install_php_version' => 'PHP versió @version@ insuficient (mínim = @minimum@)',
	'install_select_langue' => 'Seleccioneu un idioma i després feu un clic en el botó « següent » per iniciar el procés d’instal·lació.',
	'install_select_type_db' => 'Indicar el tipus de base de dades:',
	'install_select_type_mysql' => 'MySQL',
	'install_select_type_pg' => 'PostgreSQL',
	'install_select_type_sqlite2' => 'SQLite 2',
	'install_select_type_sqlite3' => 'SQLite 3',
	'install_serveur_hebergeur' => 'Servidor de base de dades atribuït per l’hostatjador',
	'install_table_prefix_hebergeur' => 'Prefix de taula donat per l’hostatjador:',
	'install_tables_base' => 'Taules de la base',
	'install_types_db_connus' => 'SPIP sap utilitzar <b>MySQL</b> (el més difós) i <b>SQLite</b>.',
	'install_types_db_connus_avertissement' => 'El suport de <b>PostgreSQL</b> és proposat igualment a títol experimental',
	'instituer_erreur_statut_a_change' => 'L’estat ja s’ha modificat',
	'instituer_erreur_statut_non_autorise' => 'No podeu escollir aquest estat',
	'intem_redacteur' => 'redactor',
	'intitule_licence' => 'Llicència',
	'item_accepter_inscriptions' => 'Acceptar les inscripcions',
	'item_activer_messages_avertissement' => 'Activar els missatges d’advertència',
	'item_administrateur_2' => 'administrador',
	'item_afficher_calendrier' => 'Mostrar en el calendari',
	'item_autoriser_syndication_integrale' => 'Difondre la totalitat dels articles als fitxers de sindicació',
	'item_choix_administrateurs' => 'els administradors',
	'item_choix_generation_miniature' => 'Generar automàticament les miniatures de les imatges.',
	'item_choix_non_generation_miniature' => 'No generar miniatures d’aquestes imatges.',
	'item_choix_redacteurs' => 'els redactors',
	'item_choix_visiteurs' => 'els visitants del lloc públic',
	'item_creer_fichiers_authent' => 'Crear els fitxers .htpasswd',
	'item_login' => 'Login',
	'item_messagerie_agenda' => 'Activar la missatgeria i l’agenda',
	'item_mots_cles_association_articles' => 'als articles',
	'item_mots_cles_association_rubriques' => 'a les seccions',
	'item_mots_cles_association_sites' => 'als llocs referenciats o sindicats.',
	'item_non' => 'No',
	'item_non_accepter_inscriptions' => 'No acceptar les inscripcions',
	'item_non_activer_messages_avertissement' => 'Sense missatges d’advertència',
	'item_non_afficher_calendrier' => 'No mostrar-ho en el calendari',
	'item_non_autoriser_syndication_integrale' => 'Només difondre un resum',
	'item_non_creer_fichiers_authent' => 'No crear aquests fitxers',
	'item_non_messagerie_agenda' => 'Desactivar la missatgeria i l’agenda',
	'item_non_publier_articles' => 'No publicar els articles abans de la data de publicació fixada.',
	'item_nouvel_auteur' => 'Nou autor',
	'item_nouvelle_rubrique' => 'Nova secció',
	'item_oui' => 'Si',
	'item_publier_articles' => 'Publicar els articles sense tenir en compte la data de la seva publicació.',
	'item_reponse_article' => 'Resposta a l’article',
	'item_version_html_max_html4' => 'Limitar l’HTML4 al lloc públic',
	'item_version_html_max_html5' => 'Permetre l’HTML5',
	'item_visiteur' => 'visitant',

	// J
	'jour_non_connu_nc' => 'n.c.',

	// L
	'label_bando_outils' => 'Barra d’eines',
	'label_bando_outils_afficher' => 'Mostrar les eines',
	'label_bando_outils_masquer' => 'Amagar les eines',
	'label_choix_langue' => 'Seleccioneu la vostra llengua',
	'label_nom_fichier_connect' => 'Indiqueu el nom utilitzat per aquest servidor',
	'label_slogan_site' => 'Eslògan del lloc',
	'label_taille_ecran' => 'Amplada de la pantalla', # MODIF
	'label_texte_et_icones_navigation' => 'Menú de navegació',
	'label_texte_et_icones_page' => 'Visualització a la pàgina',
	'ldap_correspondance' => 'herència del camp @champ@',
	'ldap_correspondance_1' => 'Herència dels camps LDAP',
	'ldap_correspondance_2' => 'Per cadascun dels camps següents d’SPIP, indiqueu el nom del camp LDAP corresponent. Deixeu-lo buit per no omplir-lo, separeu-lo amb espais o comes per assajar diversos camps LDAP.',
	'lien_ajouter_auteur' => 'Afegir aquest autor',
	'lien_ajouter_une_rubrique' => 'Afegir aquesta secció',
	'lien_email' => 'correu electrònic',
	'lien_nom_site' => 'NOM DEL LLOC:',
	'lien_retirer_auteur' => 'Retirar aquest autor',
	'lien_retirer_rubrique' => 'eliminar la secció ',
	'lien_retirer_tous_auteurs' => 'Retirar tots els autors',
	'lien_retirer_toutes_rubriques' => 'elimina totes les seccions',
	'lien_site' => 'lloc',
	'lien_tout_decocher' => 'Desmarcar tot',
	'lien_tout_deplier' => 'Obrir-ho tot',
	'lien_tout_replier' => 'Tancar-ho tot',
	'lien_tout_supprimer' => 'Suprimir-ho tot',
	'lien_trier_nom' => 'Classificar per nom',
	'lien_trier_nombre_articles' => 'Classificar per número d’articles',
	'lien_trier_statut' => 'Classificar per estat',
	'lien_voir_en_ligne' => 'VEURE EN LÍNIA:',
	'logo_article' => 'Logotip de l’article',
	'logo_auteur' => 'Logotip de l’autor',
	'logo_rubrique' => 'Logotip de la secció',
	'logo_site' => 'Logotip d’aquest lloc',
	'logo_standard_rubrique' => 'Logotip estàndard de les seccions',
	'logo_survol' => 'Logotip canviant',

	// M
	'menu_aide_installation_choix_base' => 'Trieu la vostra base de dades',
	'module_fichier_langue' => 'Fitxer de llengua',
	'module_raccourci' => 'Drecera',
	'module_texte_affiche' => 'Text publicat',
	'module_texte_explicatif' => 'Podeu inserir els recursos següents a les plantilles del vostre lloc públic. Es traduiran automàticament a les diferents llengües per les que existeix un fitxer de llengua.',
	'module_texte_traduction' => 'El fitxer de llengua « @module@ » es troba disponible a:',
	'mois_non_connu' => 'desconegut',

	// N
	'nouvelle_version_spip' => 'Està disponible la versió @version@ d’SPIP', # MODIF

	// O
	'onglet_contenu' => 'Contingut',
	'onglet_declarer_une_autre_base' => 'Declarar una altre base',
	'onglet_discuter' => 'Conversar',
	'onglet_interactivite' => 'Interactivitat',
	'onglet_proprietes' => 'Propietats',
	'onglet_repartition_actuelle' => 'actualment',
	'onglet_sous_rubriques' => 'Subseccions ',

	// P
	'page_pas_proxy' => 'Aquesta pàgina no ha de passar pel proxy',
	'pas_de_proxy_pour' => 'Si ho necessiteu, indiqueu les màquines o dominis als que aquest proxy no s’ha d’aplicar (per exemple: @exemple@)',
	'plugin_charge_paquet' => 'Càrrega del paquet @name@',
	'plugin_charger' => 'Descarregar',
	'plugin_erreur_charger' => 'error: impossible de carregar @zip@',
	'plugin_erreur_droit1' => 'El directori <code>@dest@</code> no és accessible en escriptura. ',
	'plugin_erreur_droit2' => 'Verifiqueu els drets sobre aquest directori (i creeu-los si és necessari), o instal·leu els fitxer per FTP.',
	'plugin_erreur_zip' => 'fracàs pclzip: error @status@',
	'plugin_etat_developpement' => 'en desenvolupament',
	'plugin_etat_experimental' => 'experimental',
	'plugin_etat_stable' => 'estable',
	'plugin_etat_test' => 'en prova',
	'plugin_impossible_activer' => 'Impossible activar el plugin @plugin@',
	'plugin_info_automatique1' => 'Si voleu autoritzar la instal·lació automàtica dels plugins, vulgueu:',
	'plugin_info_automatique1_lib' => 'Si voleu autoritzar la instal·lació automàtica d’aquesta llibreria, vulgueu:',
	'plugin_info_automatique2' => 'crear un directori <code>@rep@</code> ;',
	'plugin_info_automatique3' => 'verificar que el servidor està autoritzat per escriure en aquest directori.',
	'plugin_info_automatique_creer' => 'per crear a l’arrel del lloc.',
	'plugin_info_automatique_exemples' => 'exemples:',
	'plugin_info_automatique_ftp' => 'Podeu instal·lar plugins, per FTP, a dins del directori <tt>@rep@</tt>',
	'plugin_info_automatique_lib' => 'Alguns plugins demanen també poder carregar fitxers a dins del directori <code>lib/</code>, a crear eventualment a l’arrel del lloc.',
	'plugin_info_automatique_liste' => 'Les vostres llistes de plugins :',
	'plugin_info_automatique_liste_officielle' => 'els plugins oficials',
	'plugin_info_automatique_liste_update' => 'Actualitzar les llistes',
	'plugin_info_automatique_ou' => 'o...',
	'plugin_info_automatique_select' => 'Seleccioneu més avall un plugin: SPIP el baixarà i l’instal·larà a dins del directori <code>@rep@</code> ; si aquest plugin ja existeix, s’actualitzarà.',
	'plugin_info_credit' => 'Crèdits',
	'plugin_info_erreur_xml' => 'La declaració d’aquest connector és incorrecta',
	'plugin_info_install_ok' => 'Instal·lació correcta',
	'plugin_info_necessite' => 'Necessita:',
	'plugin_info_non_compatible_spip' => 'Aquest connector no és compatible amb aquesta versió d’SPIP',
	'plugin_info_plugins_dist_1' => 'Les extensions que hi ha a sota es carreguen i s’activen al directori @plugins_dist@.',
	'plugin_info_plugins_dist_2' => 'No es poden desactivar.',
	'plugin_info_telecharger' => 'baixar-lo des de @url@ i instal·lar-lo a @rep@',
	'plugin_info_upgrade_ok' => 'L’actualització ha estat exitosa',
	'plugin_librairies_installees' => 'Llibreries instal·lades',
	'plugin_necessite_lib' => 'Aquest plugin necessita la llibreria @lib@',
	'plugin_necessite_plugin' => 'Requereix el plugin @plugin@ com a mínim en la versió @version@.',
	'plugin_necessite_plugin_sans_version' => 'Requereix el plugin @plugin@',
	'plugin_necessite_spip' => 'Requereix com a mínim la versió @version@ d’SPIP.',
	'plugin_source' => 'font: ',
	'plugin_titre_automatique' => 'Instal·lació automàtica',
	'plugin_titre_automatique_ajouter' => 'Afegir plugins',
	'plugin_titre_installation' => 'Instal·lació del connector @plugin@',
	'plugin_titre_modifier' => 'els meus plugins',
	'plugin_utilise_plugin' => 'Utilitza el plugin @plugin@ a la versió @version@.',
	'plugin_zip_active' => 'Continueu per activar-lo',
	'plugin_zip_adresse' => 'indiqueu més avall l’adreça d’un fitxer zip de plugin a baixar, o fins i tot l’adreça d’una llista de plugins.',
	'plugin_zip_adresse_champ' => 'Adreça del plugin o de la llista ',
	'plugin_zip_content' => 'Conté els següents fitxers (@taille@),<br />a punt per a ser instal·lats en el directori <code>@rep@</code>',
	'plugin_zip_installe_finie' => 'El fitxer @zip@ s’ha descomprimit i instal·lat.',
	'plugin_zip_installe_rep_finie' => 'El fitxer @zip@ s’ha descomprimit i instal·lat en el directori @rep@',
	'plugin_zip_installer' => 'Ara el podeu instal·lar.',
	'plugin_zip_telecharge' => 'El fitxer @zip@ s’ha baixat',
	'plugins_actif_aucun' => 'No hi ha cap connector activat.',
	'plugins_actif_un' => 'Un connector activat.',
	'plugins_actifs' => '@count@ plugins actius.',
	'plugins_actifs_liste' => ' Actius',
	'plugins_compte' => '@count@ plugins',
	'plugins_disponible_un' => 'Un connector disponible.',
	'plugins_disponibles' => '@count@ plugins disponibles.',
	'plugins_erreur' => 'Error en els plugins: @plugins@',
	'plugins_liste' => 'Llista dels connectors',
	'plugins_liste_dist' => 'Extensions bloquejades',
	'plugins_recents' => 'Connectors recents.',
	'plugins_tous_liste' => 'Tots',
	'plugins_vue_hierarchie' => 'Jerarquia',
	'plugins_vue_liste' => 'Llista',
	'protocole_ldap' => 'Versió del protocol:',

	// Q
	'queue_executer_maintenant' => 'Executar ara',
	'queue_info_purger' => 'Vous pouvez supprimer tous les travaux en attente et ré-inialiser la liste avec les travaux périodiques', # MODIF
	'queue_nb_jobs_in_queue' => '@nb@ treballs en espera',
	'queue_next_job_in_nb_sec' => 'Proper treball en @nb@ s',
	'queue_no_job_in_queue' => 'Cap treball en espera',
	'queue_one_job_in_queue' => '1 treball en espera',
	'queue_purger_queue' => 'Purgar la llista de treballs',
	'queue_titre' => 'Llista de treballs',

	// R
	'repertoire_plugins' => 'Directori:',
	'required' => '[obligatori]',

	// S
	'sans_heure' => 'sense hora',
	'statut_admin_restreint' => '(admin restringida)',
	'statut_webmestre' => 'webmestre',

	// T
	'tache_cron_asap' => 'Tasca CRON @function@ (ASAP)',
	'tache_cron_secondes' => 'Tasca CRON @function@ (toutes les @nb@ s)',
	'taille_cache_image' => 'Les imatges calculades automàticament per SPIP (miniatures dels documents, títols presentats en forma gràfica, función matemàtiques en format TeX...) ocupen en el directori @dir@ un total de @taille@.',
	'taille_cache_infinie' => 'Aquest lloc Web no preveu limitar la mida del directori de la memòria cau (cache).',
	'taille_cache_maxi' => 'SPIP prova de limitar la mida del directori de la memòria cau (cache) d’aquest lloc a aproximadament <b>@octets@</b> de dades.',
	'taille_cache_moins_de' => 'La mida de la memòria cau és de menys de @octets@.',
	'taille_cache_octets' => 'La mida de la memòria cau és actualment de @octets@.',
	'taille_cache_vide' => 'La memòria cau està buida.',
	'taille_repertoire_cache' => 'Mida del directori de la memòria cau',
	'text_article_propose_publication' => 'Article proposat per ser publicat.',
	'texte_acces_ldap_anonyme_1' => 'Alguns servidors LDAP no accepten accessos anònims. En aquest cas és necessari especificar un identificador d’accés inicial per tal de poder buscar informacions en el directori. En la majoria de casos tanmateix, els camps següents es podrán deixar buits.',
	'texte_admin_effacer_01' => 'Aquesta comanda esborra <i>tot</i> el contingut de la base de dades,
la qual compren <i>tots</i> els accessos dels redactors i administradors. Després d’haver-la executat, haureu de reinstal.lar l’SPIP per refer una nova base i un primer accés per l’administrador.',
	'texte_adresse_annuaire_1' => '(Si el vostre anuari està instal.lat a la mateixa maquina que aquesta web, es tracta probablement de "localhost".)',
	'texte_ajout_auteur' => 'L’autor següent ha estat afegit a l’article:',
	'texte_annuaire_ldap_1' => 'Si se disposa d’un accés a un anuari (LDAP), es pot utilitzar per a importar automàticament els/les usuaris/es baix SPIP.',
	'texte_article_statut' => 'Aquest article està:',
	'texte_article_virtuel' => ' Article virtual',
	'texte_article_virtuel_reference' => ' <b>Article virtual:</b> article referenciat en la web amb SPIP, però redirigit cap un altre URL. Per suprimir la redirecció, esborreu l’URL que apareix dalt.',
	'texte_aucun_resultat_auteur' => 'Cap resultat per "@cherche_auteur@"',
	'texte_auteur_messagerie' => 'Aquest lloc us pot mostrar permanentment la llista dels redactors que estan connectats, permetent-vos intercanviar missatges en directe. Podeu decidir no aparèixer en aquesta llista (i ser «invisibles» pels altres usuaris).',
	'texte_auteurs' => 'ELS AUTORS',
	'texte_choix_base_1' => 'Trie la seua base:',
	'texte_choix_base_2' => 'El servidor SQL conté diverses bases de dades.',
	'texte_choix_base_3' => '<b>Seleccioneu</b> d’aquí sota quina us ha estat atribuïda pel vostre proveïdor d’hostatge:',
	'texte_choix_table_prefix' => 'Prefix de les taules:',
	'texte_compatibilite_html' => 'Podeu demanar a SPIP que produeixi, al lloc públic, codi compatible amb la norma <i>HTML4</i>, o permetre-li utilitzar les possibilitats més modernes de l’<i>HTML5</i>.',
	'texte_compatibilite_html_attention' => 'No hi ha cap risc activant la opció <i>HTML5</i>, però si ho feu, les pàgines del vostre lloc, si voleu que siguin vàlides, hauran de començar per la següent menció: <code>&lt;!DOCTYPE html&gt;</code>.',
	'texte_compte_element' => ' @count@ element',
	'texte_compte_elements' => ' @count@ elements',
	'texte_conflit_edition_correction' => 'Vulgueu controlar més avall les diferències entre les dues versions del text; podeu també copiar les vostres modificacions, i després començar de nou. ',
	'texte_connexion_mysql' => 'Consulteu les informacions aportades pel vostre proveïdor d’hostatge: heu de trobar-hi el servidor de base de dades que proposa i els identificadors personals per connectar-vos-hi.',
	'texte_contenu_article' => ' (Contingut de l’article en poques paraules.)',
	'texte_contenu_articles' => 'Segons l’esquelet triat per la vostra web, podeu decidir
 que certs elements dels articles  no siguen emprats.
 Useu la llista d’ací baix per a indicar quins elements estaran disponibles.',
	'texte_crash_base' => 'Si la bbdd ha deixat de funcionar correctament, es pot intentar fer una reparació automàtica.',
	'texte_creer_rubrique' => 'Abans de poder escriure els articles, <br /> heu de crear una secció.',
	'texte_date_creation_article' => 'DATA DE CREACIÓ DE L’ARTICLE :',
	'texte_date_creation_objet' => 'Data de creació', # on ajoute le ":"
	'texte_date_publication_anterieure' => 'Data de redacció anterior:',
	'texte_date_publication_anterieure_nonaffichee' => 'No publicar els articles de data de redacció anterior.',
	'texte_date_publication_article' => 'DATA DE PUBLICACIÓ EN LÍNIA :',
	'texte_date_publication_objet' => 'Data de publicació en línia',
	'texte_descriptif_rapide' => 'Descripció ràpida',
	'texte_effacer_base' => 'Esborrar la base de dades SPIP',
	'texte_effacer_statistiques' => 'Esborrar les estadístiques',
	'texte_en_cours_validation' => 'Els continguts que hi ha aquí a sota estan a l’espera de ser validats. ',
	'texte_enrichir_mise_a_jour' => 'Podeu enriquir la compaginació del text emprant "dreceres tipogràfiques".',
	'texte_fichier_authent' => '<b>SPIP ha de crear els fitxers especials
 <tt>.htpasswd</tt> i <tt>.htpasswd-admin</tt> en el 
directori @dossier@ ?</b>
<p> Aquests fitxers us poden servir per restringir l’accés als autors i als administradors a altres llocs de la vostra Web (programa extern d’estadístiques, per exemple).</p>
 Si no li veieu cap utilitat, podeu deixar aquesta opció en el seu valor per defecte (no hi ha  creació de fitxers).</p>',
	'texte_informations_personnelles_1' => ' El sistema va ara a fer-vos un accés personalitzat al web.',
	'texte_informations_personnelles_2' => ' (Nota: si es tracta d’una reinstal.lació, si el vostre accés funciona encara vostès poden',
	'texte_introductif_article' => ' (Texte introductiu de l’article.)',
	'texte_jeu_caractere' => 'És aconsellable utilitzar, al vostre lloc Web, l’alfabet universal (<tt>utf-8</tt>) : aquest permet la presentació de texts en totes les llengües, i no posa problemes de compatibilitat amb els navegadors moderns.',
	'texte_jeu_caractere_3' => 'Actualment el vostre lloc Web està configurat amb el joc de caràcters:',
	'texte_jeu_caractere_4' => 'Si això no correspon a la realitat de les vostres dades (com a conseqüència, per exemple, d’una restauració de la base de dades), o si <em>inicieu aquest lloc Web</em> i desitgeu inicialitzar amb un altre joc de caràcters, vulgueu indicar-lo aquí:',
	'texte_login_ldap_1' => '(Deixar buit per un accés anònim, o ficar l’ordre sencera, per exemple " <tt>uid=Ferrer, ou=users, dc=el-meu-domini, dc=com</tt>".)',
	'texte_login_precaution' => 'Atenció! Aquest és el login o nom d’usuari amb el qual esteu connectats actualment.
Useu aquest formulari amb precaució...',
	'texte_messagerie_agenda' => 'Una missatgeria permet als redactors del lloc comunicar-se entre ells directament a l’espai privat del lloc Web. Està associada a una agenda. ',
	'texte_mise_a_niveau_base_1' => 'S’han actualitzat els fitxers d’SPIP.
 Cal ara actualitzar la base de dades del lloc.',
	'texte_modifier_article' => 'Modificar l’article:',
	'texte_multilinguisme' => 'Si es desitja es pot generar els articles es diversos idiomes, amb una navegació complexa, es pot també afegir un menú per seleccionar l’idioma dels articles i/o de les seccions, en funció de l’organització del lloc web.',
	'texte_multilinguisme_trad' => 'Es pot igualment activar un sistema de gestió d’enllaços entre les diferents traduccions de certs objectes.',
	'texte_non_compresse' => ' <i>no comprimit</i> (el servidor no suporta aquesta funcionalitat)',
	'texte_nouvelle_version_spip_1' => 'Heu instal.lat una nova versió d’SPIP.',
	'texte_nouvelle_version_spip_2' => 'Aquesta nova versió necessita una actualització més complerta que la normal. Si sou el webmestre del lloc, esborreu el fitxer @connect@ i repreneu la instal·lació per tal d’actualitzar els paràmetres de connexió a la base de dades.<p> (NB.: si heu oblidat els vostres paràmetres de connexió, doneu un cop d’ull al fitxer @connect@ abans de suprimir-lo...)</p>',
	'texte_operation_echec' => 'Torneu a la pàgina anterior, seleccioneu una altra base o creeu-ne una de nova. Verifiqueu les dades donades pel vostre proveïdor d’hostatge.',
	'texte_plus_trois_car' => 'més de 3 caràcters',
	'texte_plusieurs_articles' => 'Diversos autors trobats per  "@cherche_auteur@":',
	'texte_port_annuaire' => ' (El valor indicat per defecte es en general convenient.)',
	'texte_presente_plugin' => 'Aquesta pàgina llista els connectors disponibles al vostre lloc Web. Podeu activar els connectors marcant la casella corresponent.',
	'texte_proposer_publication' => 'Quan un article està acabat, <br /> podeu proposar la seva publicació.',
	'texte_proxy' => 'En alguns casos (intranet, xarxes protegides), els llocs distants (documentació d’SPIP, llocs Web sindicats, etc.) només són accessibles per mitjà d’un <i>proxy HTTP</i>. En aquest cas, indiqueu a continuació la seva adreça, en la forma @proxy_en_cours@. En general, deixareu buida aquesta opció.',
	'texte_publication_articles_post_dates' => 'Que ha de fer SPIP quan els articles tinguin una data de publicació posterior a l’actual?',
	'texte_rappel_selection_champs' => ' [No oblide pas seleccionar correctament aquest camp.]',
	'texte_recalcul_page' => 'Si es vol recarregar una sola pàgina, cal passar abans per l’espai públic i premer el botó "recarregar".',
	'texte_recuperer_base' => 'Reparar la base de dades',
	'texte_reference_mais_redirige' => 'article referenciat a la web SPIP, pero redirigit cap a un altre URL.',
	'texte_requetes_echouent' => '<b>Quan algunes peticions SQL fracassen sistemàticament i sense cap raó aparent, és possible que sigui per culpa de la pròpia base de dades.</b><p>
El vostre servidor SQL disposa d’una facultat de reparació de les seves taules quan aquestes s’han deteriorat per accident. Aquí podeu intentar aquesta reparació; en cas de fracàs, conserveu una còpia del resultat ja que possiblement conté indicis de quines coses no funcionen...</p><p>
  Si el problema persisteix, poseu-vos en contacte amb el vostre proveïdor d’allotjament.</p>',
	'texte_selection_langue_principale' => 'A continuació podeu seleccionar la «llengua principal» del lloc. Aquesta selecció no us obliga - afortunadament! - a escriure els vostres articles en la llengua escollida, però permet determinar:
<ul><li> el format per defecte de les dates en el lloc públic;</li>
<li> la naturalesa del motor tipogràfic que l’SPIP ha d’utilitzar per la reproducció dels textos;</li>
<li> l’idioma utilitzat en els formularis del lloc públic;</li>
<li> l’idioma mostrat per defecte en l’espai privat.</li></ul>',
	'texte_sous_titre' => 'Subtítol',
	'texte_statistiques_visites' => '(columnes sombrejades:  diumenge/corba obscura: evolució de la mitjana)',
	'texte_statut_attente_validation' => 'esperant la validació',
	'texte_statut_publies' => 'publicats en línia',
	'texte_statut_refuses' => 'refusats',
	'texte_suppression_fichiers' => 'Useu aquesta comanda per suprimir tots els fitxers presents
a la caché d’SPIP. Això permet per exemple forçar un recàlcul de totes les pàgines si s’ha
fet modificacions importants gràficament o estructurals del lloc web.',
	'texte_sur_titre' => 'Sobretítol',
	'texte_table_ok' => ': aquesta taula està OK.',
	'texte_tentative_recuperation' => 'Intent de reparació',
	'texte_tenter_reparation' => 'Intentar una reparació de la base de dades',
	'texte_test_proxy' => 'Per fer una prova d’aquest proxy, indicar ací l’adreça del lloc Web
que es vol testar.',
	'texte_titre_02' => 'Títol:',
	'texte_titre_obligatoire' => '<b>Títol</b> [Obligatori]',
	'texte_travail_article' => '@nom_auteur_modif@ ha treballat amb aquest article fa @date_diff@ minuts',
	'texte_travail_collaboratif' => 'Si és freqüent que diversos redactors treballin en un mateix article, el sistema pot mostrar els articles "oberts" recentment per tal d’evitar les modificacions simultànies.
Aquesta opció està desactivada per defecte amb la finalitat d’evitar mostrar  missatges d’advertència intempestius.',
	'texte_vide' => 'buit',
	'texte_vider_cache' => 'buidar la memòria cau',
	'titre_admin_tech' => 'Manteniment tècnic',
	'titre_admin_vider' => 'Manteniment tècnic',
	'titre_ajouter_un_auteur' => 'Afegir un autor',
	'titre_ajouter_un_mot' => 'Afegir una paraula clau',
	'titre_cadre_afficher_article' => 'Afegir els articles',
	'titre_cadre_afficher_traductions' => 'Mostrar l’estat de les traduccions per les següents llengües:',
	'titre_cadre_ajouter_auteur' => 'AFEGIR UN AUTOR:',
	'titre_cadre_interieur_rubrique' => 'A l’interior de la secció',
	'titre_cadre_numero_auteur' => 'AUTOR NÚMERO',
	'titre_cadre_numero_objet' => '@objet@ NÚMERO:',
	'titre_cadre_signature_obligatoire' => '<b>Signatura</b> [Obligatòria]<br />',
	'titre_config_contenu_notifications' => 'Notificacions',
	'titre_config_contenu_prive' => 'A l’espai privat',
	'titre_config_contenu_public' => 'Al lloc públic',
	'titre_config_fonctions' => 'Configuració del web',
	'titre_config_langage' => 'Configurar la llengua',
	'titre_configuration' => 'Configuració del lloc',
	'titre_configurer_preferences' => 'Configurar les vostres preferències',
	'titre_conflit_edition' => 'Conflicte durant l’edició',
	'titre_connexion_ldap' => 'Opcions: <b>Vostre connexió LDAP</b>',
	'titre_groupe_mots' => 'GRUP DE MOTS:',
	'titre_identite_site' => 'Identitat del lloc',
	'titre_langue_article' => 'Llengua de l’article',
	'titre_langue_rubrique' => 'Llengua de la secció',
	'titre_langue_trad_article' => 'LLENGUA I TRADUCCIONS DE L’ARTICLE',
	'titre_les_articles' => 'ELS ARTICLES',
	'titre_messagerie_agenda' => 'Missatgeria i agenda',
	'titre_naviguer_dans_le_site' => 'Navegar dins el web...',
	'titre_nouvelle_rubrique' => 'Nova secció',
	'titre_numero_rubrique' => 'SECCIÓ NÚMERO:',
	'titre_page_articles_edit' => 'Modificar: @titre@',
	'titre_page_articles_page' => 'Els articles',
	'titre_page_articles_tous' => 'Tota la web',
	'titre_page_calendrier' => 'Calendari @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'Configuració del lloc',
	'titre_page_delete_all' => 'supresió total i irreversible',
	'titre_page_recherche' => ' Resultats de la recerca @recherche@',
	'titre_page_statistiques_referers' => 'Estadistiques (vincles entrants)',
	'titre_page_upgrade' => 'Actualitzar SPIP',
	'titre_publication_articles_post_dates' => 'Publicació dels articles datats posteriorment',
	'titre_reparation' => ' Reparació',
	'titre_suivi_petition' => 'Seguiment de les peticions',
	'tls_ldap' => 'Transport Layer Security:',
	'trad_article_traduction' => 'Totes les versions d’aquest article:',
	'trad_delier' => 'No enllaçar amb aquestes traduccions',
	'trad_lier' => 'Aquest article és una traducció de l’article número:',
	'trad_new' => 'Escriure una nova traducció',

	// U
	'utf8_convert_erreur_orig' => 'Error: no es permet l’ús del joc de caràcters @charset@.',

	// V
	'version' => 'Versió:'
);

?>
